REST API for Humans
===================
I have been introducing Eve at several conferences and meetups. A few people
suggested that I post the slides on the Eve website, so here it is: a quick
rundown on Eve features, along with a few code snippets and examples. Hopefully
it will do a good job in letting you decide whether Eve is valid solution for
your use case.

.. embedly:: http://speakerdeck.com/nicola/eve-rest-api-for-humans

Conferences
------------
Eve REST API for Humans™ has been presented at the following events so far:

- Percona Live 2015, Amsterdam
- EuroPython 2014, Berlin
- Python Meetup, Helsinki 
- PyCon Italy 2014, Florence 
- PyCon Sweden 2014, Stockholm 
- FOSDEM 2014, Brussels 
